#######
Changes
#######

* 2011-08-23: **1.0.1**

  Enhancements:

  * Changed DPO7104 to use "fastframe" averaging

  Fixes:

  * Minor documentation updates

* 2011-08-22: **1.0.0**

  The initial release.
